@@ -21,6 +21,7 @@ from pikepdf import jbig2
 from pikepdf._core import Buffer, Pdf, PdfError, StreamDecodeLevel
 from pikepdf._exceptions import DependencyError
 from pikepdf.models import _transcoding
+from pikepdf.models._transcoding import ImageDecompressionError
 from pikepdf.objects import (
     Array,
     Dictionary,
@@ -161,7 +162,7 @@ class PdfImageBase(ABC):
 
         if self.colorspace in ('/DeviceGray', '/CalGray'):
             return (0.0, 1.0)
-        if self.colorspace == ('/DeviceRGB', '/CalRGB'):
+        if self.colorspace in ('/DeviceRGB', '/CalRGB'):
             return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
         if self.colorspace == '/DeviceCMYK':
             return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
@@ -1046,3 +1047,19 @@ class PdfInlineImage(PdfImageBase):
         """Return decompressed stream buffer."""
         # qpdf does not have an API to return this directly, so convert it.
         return self._convert_to_pdfimage().get_stream_buffer()
+
+
+__all__ = [
+    'CMYKDecodeArray',
+    'DecodeArray',
+    'HifiPrintImageNotTranscodableError',
+    'ImageDecompressionError',
+    'InvalidPdfImageError',
+    'PaletteData',
+    'PdfImage',
+    'PdfImageBase',
+    'PdfInlineImage',
+    'PdfJpxImage',
+    'RGBDecodeArray',
+    'UnsupportedImageTypeError',
+]
