@@ -16,10 +16,10 @@ from typing import TYPE_CHECKING, Any, Callable, NamedTuple
 from warnings import warn
 
 from lxml import etree
-from lxml.etree import QName, XMLSyntaxError
+from lxml.etree import QName, XMLSyntaxError, _Element
 
 from pikepdf._version import __version__ as pikepdf_version
-from pikepdf._xml import _Element, parse_xml
+from pikepdf._xml import parse_xml
 from pikepdf.objects import Name, Stream, String
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -823,14 +823,15 @@ class PdfMetadata(MutableMapping):
             node = etree.SubElement(rdfdesc, self._qname(key))
             self._setitem_add_array(node, val)
         elif isinstance(val, str):
-            _rdfdesc = etree.SubElement(
-                rdf,
-                str(QName(XMP_NS_RDF, 'Description')),
-                attrib={
-                    QName(XMP_NS_RDF, 'about'): '',
-                    self._qname(key): _clean(val),
-                },
-            )
+            rdfdesc = rdf.find('rdf:Description[@rdf:about=""]', self.NS)
+            if rdfdesc is None:
+                rdfdesc = etree.SubElement(
+                    rdf,
+                    str(QName(XMP_NS_RDF, 'Description')),
+                    attrib={str(QName(XMP_NS_RDF, 'about')): ''},
+                )
+            node = etree.SubElement(rdfdesc, self._qname(key))
+            node.text = _clean(val)
         else:
             raise TypeError(f"Setting {key} to {val} with type {type(val)}") from None
 
