@@ -6,11 +6,13 @@
 
 from __future__ import annotations
 
+from collections.abc import Iterable
 from enum import Enum
 from itertools import chain
-from typing import Iterable, List, cast
+from typing import cast
 
-from pikepdf import Array, Dictionary, Name, Object, Page, Pdf, String
+from pikepdf._core import Page, Pdf
+from pikepdf.objects import Array, Dictionary, Name, Object, String
 
 
 class PageLocation(Enum):
@@ -48,8 +50,7 @@ def make_page_destination(
     bottom: float | None = None,
     zoom: float | None = None,
 ) -> Array:
-    """
-    Create a destination ``Array`` with reference to a Pdf document's page number.
+    """Create a destination ``Array`` with reference to a Pdf document's page number.
 
     Arguments:
         pdf: PDF document object.
@@ -157,6 +158,7 @@ class OutlineItem:
         bottom: float | None = None,
         zoom: float | None = None,
     ):
+        """Initialize OutlineItem."""
         self.title = title
         self.destination = destination
         self.page_location = page_location
@@ -187,10 +189,16 @@ class OutlineItem:
                 dest = page.label
             elif isinstance(self.destination, String):
                 # 12.3.2.2 Named destination, byte string reference to Names
-                dest = f'<Named Destination in document .Root.Names dictionary: {self.destination}>'
+                dest = (
+                    f"<Named Destination in document .Root.Names dictionary: "
+                    f"{self.destination}>"
+                )
             elif isinstance(self.destination, Name):
                 # 12.3.2.2 Named destination, name object (PDF 1.1)
-                dest = f'<Named Destination in document .Root.Dests dictionary: {self.destination}>'
+                dest = (
+                    f"<Named Destination in document .Root.Dests dictionary: "
+                    f"{self.destination}>"
+                )
             elif isinstance(self.destination, int):
                 # Page number
                 dest = f'<Page {self.destination}>'
@@ -203,7 +211,7 @@ class OutlineItem:
 
     @classmethod
     def from_dictionary_object(cls, obj: Dictionary):
-        """Creates a ``OutlineItem`` from a ``Dictionary``.
+        """Create a ``OutlineItem`` from a ``Dictionary``.
 
         Does not process nested items.
 
@@ -227,7 +235,7 @@ class OutlineItem:
         return cls(title, destination=destination, action=action, obj=obj)
 
     def to_dictionary_object(self, pdf: Pdf, create_new: bool = False) -> Dictionary:
-        """Creates/updates a ``Dictionary`` object from this outline node.
+        """Create/update a ``Dictionary`` object from this outline node.
 
         Page numbers are resolved to a page reference on the input
         ``Pdf`` object.
@@ -263,7 +271,7 @@ class OutlineItem:
 class Outline:
     """Maintains a intuitive interface for creating and editing PDF document outlines.
 
-    See |pdfrm| section 12.3.
+    See {{ pdfrm }} section 12.3.
 
     Arguments:
         pdf: PDF document object.
@@ -279,6 +287,7 @@ class Outline:
     """
 
     def __init__(self, pdf: Pdf, max_depth: int = 15, strict: bool = False):
+        """Initialize Outline."""
         self._root: list[OutlineItem] | None = None
         self._pdf = pdf
         self._max_depth = max_depth
@@ -291,6 +300,15 @@ class Outline:
     def __repr__(self):
         return f'<pikepdf.{self.__class__.__name__}: {len(self.root)} items>'
 
+    def _repr_pretty_(self, p, cycle):
+        if cycle:
+            p.text("...")
+        else:
+            with p.group(2, "pikepdf.models.outlines.Outline<\n", "\n>"):
+                for _, item in enumerate(self.root):
+                    p.breakable()
+                    p.pretty(str(item))
+
     def __enter__(self):
         self._updating = True
         return self
@@ -413,9 +431,41 @@ class Outline:
         if first_obj:
             self._load_level_outline(first_obj, root, 0, set())
 
+    def add(self, title: str, destination: Array | int | None) -> OutlineItem:
+        """Add an item to the outline.
+
+        Arguments:
+            title: Title of the outline item.
+            destination: Destination to jump to when the item is selected.
+
+        Returns:
+            The newly created :class:`OutlineItem`.
+        """
+        if self._root is None:
+            self._load()
+        item = OutlineItem(title, destination)
+        if self._root is None:
+            self._root = [item]
+        else:
+            self._root.append(item)
+        if not self._updating:
+            self._save()
+        return item
+
     @property
     def root(self) -> list[OutlineItem]:
         """Return the root node of the outline."""
         if self._root is None:
             self._load()
-        return cast(List[OutlineItem], self._root)
+        return cast(list[OutlineItem], self._root)
+
+    @root.setter
+    def root(self, new_root: list[OutlineItem]):
+        """Set the root node of the outline."""
+        if not isinstance(new_root, list):
+            raise ValueError("Root must be a list of OutlineItem objects.")
+        for item in new_root:
+            if not isinstance(item, OutlineItem):
+                raise ValueError("Each item in root must be an OutlineItem.")
+
+        self._root = new_root
